@@ -1,13 +1,13 @@
-import numpy as np
+import numpy
 import xarray
 import matplotlib.pyplot as plt
-class earthobj:
-    def __init__(self,DataArray):
+
+class plotshow():
+    def __init__(self,DataArray,lst=True):
         self.DataArray = DataArray
-    def testprint(self):
-        print('Done')
-    def plotshow(self,lst=True):
         self.lst=lst
+
+    def plotshow(self):
         if type(self.DataArray) == xarray.core.dataarray.DataArray:
             if self.lst==True:
                 ymax = 0 ; ymin = self.DataArray.shape[0]
